@@ -603,15 +603,27 @@ fn to_agg_select<'a>(exp: &Option<Expression>, agg: &syn::Ident,
 
     // 根据表达式类型确定聚集后的类型
     let type_gen = match *ty {
-        Type::Double => quote! { ::<f64> },
-        Type::Int => quote! { ::<i32> },
+        Type::Double => {
+            match agg{
+                _ if agg.to_string() == "max" => quote! {max_by(|a, b| a.partial_cmp(b).unwrap()).unwrap_or_default },
+                _ if agg.to_string() == "min" => quote! {min_by(|a, b| a.partial_cmp(b).unwrap()).unwrap_or_default },
+                _ => quote! { #agg::<f64> },
+            }
+        }
+        Type::Int => {
+            match agg {
+                _ if agg.to_string() == "max" => quote! { #agg().unwrap_or_default },
+                _ if agg.to_string() == "min" => quote! { #agg().unwrap_or_default },
+                _ => quote! { #agg::<i32> },
+            }
+         },
         // 无类型，目前只有count，不加类型
-        Type::None => quote! {},
-        _ => panic!("表达式类型错误：{:?}", ty)
+        Type::None => quote! {#agg},
+        _ => panic!("表达式类型错误：{:?}", ty),
     };
 
     // 返回映射后的函数调用
-    let result = quote! { #select.#agg#type_gen() };
+    let result = quote! { #select.#type_gen() };
     result
 }
 
